# Python Statistic Program 
> My Statistic Tools made with Python 

### Features
- Frequency Table
- Descriptive Statistics
- Display Chart
- Data Transformation

### Required
- Matplotlib
- Matplotlib_Venn
- Numpy
- Tabulate
- Pandas
- Scipy

### Structure
- Program Structure

      + Main.py                [ Main Control file ]
      + FrequencyTable.py      [ Frequency Table Module ]
      + Chart.py               [ Chart Display Module ]
      + Transform.py           [ Data Transformation Module ]

### How to Use
- For detailed Documentation, please visit [Pythistic Wiki](https://github.com/brotherzhafif/Pythistic/wiki)

### Author
    BrotherZhafif
